Re: [PATCH RFC 2/7] filemap: Change mapping_set_folio_min_order() -> mapping_set_folio_orders()

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



On 25/04/2024 15:47, Pankaj Raghav (Samsung) wrote:
On Mon, Apr 22, 2024 at 02:39:18PM +0000, John Garry wrote:
Borrowed from:

https://urldefense.com/v3/__https://lore.kernel.org/linux-fsdevel/20240213093713.1753368-2-kernel@xxxxxxxxxxxxxxxx/__;!!ACWV5N9M2RV99hQ!LvajFab0xQx8oBWDlDtVY8duiLDjOKX91G4YqadoCu6gqatA2H0FzBUvdSC69dqXNoe2QvStSwrxIZ142MXOKk8$
(credit given in due course)

We will need to be able to only use a single folio order for buffered
atomic writes, so allow the mapping folio order min and max be set.


We still have the restriction of not being able to support order-1
folios - it will be required to lift this limit at some stage.

This is already supported upstream for file-backed folios:
commit: 8897277acfef7f70fdecc054073bea2542fc7a1b

ok


index fc8eb9c94e9c..c22455fa28a1 100644
diff --git a/mm/filemap.c b/mm/filemap.c
index d81530b0aac0..d5effe50ddcb 100644
--- a/mm/filemap.c
+++ b/mm/filemap.c
@@ -1898,9 +1898,15 @@ struct folio *__filemap_get_folio(struct address_space *mapping, pgoff_t index,
  no_page:
  	if (!folio && (fgp_flags & FGP_CREAT)) {
  		unsigned int min_order = mapping_min_folio_order(mapping);
-		unsigned int order = max(min_order, FGF_GET_ORDER(fgp_flags));
+		unsigned int max_order = mapping_max_folio_order(mapping);
+		unsigned int order = FGF_GET_ORDER(fgp_flags);
  		int err;
+ if (order > max_order)
+			order = max_order;
+		else if (order < min_order)
+			order = max_order;

order = min_order; ?

right

Thanks,
John




[Index of Archives]     [Linux ARM Kernel]     [Linux ARM]     [Linux Omap]     [Fedora ARM]     [IETF Annouce]     [Bugtraq]     [Linux OMAP]     [Linux MIPS]     [eCos]     [Asterisk Internet PBX]     [Linux API]

  Powered by Linux
--- a/include/linux/pagemap.h
+++ b/include/linux/pagemap.h
@@ -363,9 +363,10 @@ static inline void mapping_set_gfp_mask(struct address_space *m, gfp_t mask)
  #endif
/*
  * mapping_set_folio_min_order() - Set the minimum folio order

In the new series (sorry forgot to CC you),

no worries, I saw it

I added a new helper called
mapping_set_folio_order_range() which does something similar to avoid
confusion based on willy's suggestion:
https://urldefense.com/v3/__https://lore.kernel.org/linux-xfs/20240425113746.335530-3-kernel@xxxxxxxxxxxxxxxx/__;!!ACWV5N9M2RV99hQ!LvajFab0xQx8oBWDlDtVY8duiLDjOKX91G4YqadoCu6gqatA2H0FzBUvdSC69dqXNoe2QvStSwrxIZ14opzAoso$


Fine, I can include that

mapping_set_folio_min_order() also sets max folio order to be
MAX_PAGECACHE_ORDER order anyway. So no need of explicitly calling it
here?


Here mapping_set_folio_min_order() is being replaced with mapping_set_folio_order_range(), so not sure why you mention that. Regardless, I'll use your mapping_set_folio_order_range().

  /**
@@ -400,7 +406,7 @@ static inline void mapping_set_folio_min_order(struct address_space *mapping,
   */
  static inline void mapping_set_large_folios(struct address_space *mapping)
  {
-	mapping_set_folio_min_order(mapping, 0);
+	mapping_set_folio_orders(mapping, 0, MAX_PAGECACHE_ORDER);
  }
@@ -363,9 +363,10 @@ static inline void mapping_set_gfp_mask(struct address_space *m, gfp_t mask)
  #endif
/*
- * mapping_set_folio_min_order() - Set the minimum folio order
+ * mapping_set_folio_orders() - Set the minimum and max folio order

In the new series (sorry forgot to CC you),
static inline unsigned int mapping_max_folio_order(struct address_space *mapping)